@@ -13,17 +13,11 @@
 DataStoragePlotter.__bases__:
   DIRAC.AccountingSystem.private.Plotters.BaseReporter.BaseReporter
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK, S_ERROR
 from DIRAC.AccountingSystem.private.Plotters.BaseReporter import BaseReporter
 
 from LHCbDIRAC.AccountingSystem.Client.Types.DataStorage import DataStorage
 
-__RCSID__ = "$Id$"
-
 # FIXME: refactor _reportMethods
 # FIXME: refactor _plotMethods
 
