@@ -9,16 +9,9 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Base Entity System client."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from LHCbDIRAC.BookkeepingSystem.Client.BaseESManager import BaseESManager
 
 
-__RCSID__ = "$Id$"
-
-
 class BaseESClient(object):
     """Basic client."""
 
