@@ -22,10 +22,6 @@ Whatever:
     'Production':7421
   }
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tempfile
 import six
 
@@ -37,8 +33,6 @@ from LHCbDIRAC.BookkeepingSystem.Client import JEncoder
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequestClient import ProductionRequestClient
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
-__RCSID__ = "$Id$"
-
 
 @createClient("Bookkeeping/BookkeepingManager")
 class BookkeepingClient(Client):
