@@ -10,17 +10,10 @@
 ###############################################################################
 """ JSON encoder - slighltly modified version for LHCbDIRAC purposes
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import json
 import datetime
 
 
-__RCSID__ = "$Id$"
-
-
 class JSONDateTimeEncoder(json.JSONEncoder):
     """encoder of datetime objects."""
 
