@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Bookkeeping file system."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import sys
 import cmd
 import pydoc
@@ -23,10 +19,7 @@ from DIRAC.DataManagementSystem.Utilities.DMSHelpers import DMSHelpers
 from LHCbDIRAC.Interfaces.API.DiracLHCb import DiracLHCb
 from LHCbDIRAC.BookkeepingSystem.Client.LHCB_BKKDBClient import LHCB_BKKDBClient
 
-__RCSID__ = "$Id$"
 
-
-#############################################################################
 class LHCbBookkeepingCLI(cmd.Cmd):
     """class."""
 
