@@ -9,9 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """LHCb Bookkeeping database manager."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import os
 import time
 
@@ -23,8 +20,6 @@ from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClie
 from LHCbDIRAC.BookkeepingSystem.Client import objects
 from LHCbDIRAC.BookkeepingSystem.Client.Help import Help
 
-__RCSID__ = "$Id$"
-
 INTERNAL_PATH_SEPARATOR = "/"
 
 #############################################################################
