@@ -9,19 +9,12 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """reimplementation of the dictionary."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from six.moves import UserDict
 
 from DIRAC import gLogger
 from LHCbDIRAC.BookkeepingSystem.Client import IndentMaker
 
 
-__RCSID__ = "$Id$"
-
-
 class odict(UserDict):
     """user defined dictionary."""
 
