@@ -9,13 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Bookkeeping utilities."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
-
 from DIRAC import gLogger, S_ERROR
 
 from DIRAC.FrameworkSystem.Client.NotificationClient import NotificationClient
