@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """BookkeepingManager service is the front-end to the Bookkeeping database."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import six
 
 from DIRAC import gLogger, S_OK, S_ERROR
@@ -28,8 +24,6 @@ from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.XMLFilesReaderManager import
 from LHCbDIRAC.BookkeepingSystem.Client import JEncoder
 from LHCbDIRAC.BookkeepingSystem.DB.Utilities import checkEnoughBKArguments
 
-__RCSID__ = "$Id$"
-
 # pylint: disable=invalid-name
 
 
@@ -915,6 +909,15 @@ class BookkeepingManagerHandler(RequestHandler):
         and replica."""
         return cls.bkkDB.getProductionFiles(prod, fileType, replica)
 
+    #############################################################################
+    types_getProductionFilesBulk = [list, six.string_types]
+
+    @classmethod
+    def export_getProductionFilesBulk(cls, prods, fileType, replica=default):
+        """It returns files and their metadata for list of productions, file type
+        and replica."""
+        return cls.bkkDB.getProductionFilesBulk(prods, fileType, replica)
+
     #############################################################################
     types_getAvailableRunNumbers = []
 
