@@ -9,14 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """stores the data taking conditions."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import gLogger
 
-__RCSID__ = "$Id$"
-
 
 class DataTakingConditions(object):
     """DataTakingConditions class."""
