@@ -9,11 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """declare a file parameter."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
 
 
 class FileParam(object):
