@@ -9,14 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """stores the input files."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.File import File
 
-__RCSID__ = "$Id$"
-
 
 class InputFile(File):
     """InputFile class."""
