@@ -9,14 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """stores the file parameters."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Replica.Replica import Replica
 
-__RCSID__ = "$Id$"
-
 
 class FileReplica(Replica):
     """FileReplica class."""
