@@ -16,12 +16,6 @@ The "<File>" lists the event types on which to operate. Each line must
 have the following format: EVTTYPEID="<evant id>",
 DESCRIPTION="<description>", PRIMARY="<primary description>"
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import re
 import DIRAC
 from DIRAC import gLogger
