@@ -11,12 +11,6 @@
 ###############################################################################
 """List all BK paths matching a wildcard path ('...' is the wildcard character,
 or '*' but enclose with quotes)"""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
