@@ -10,9 +10,6 @@
 ###############################################################################
 """Reads .log-files and outputs summary of counters as a .json-file and a
 .html-file."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import os
 import json
 
