@@ -18,18 +18,12 @@ to the right queue, which is also specified in the configuration. The
 message is built using a dictionary passed to one of the methods, which
 should contain the keys 'SAMResults' 'SAMDetails' 'GridRequiredCEs'.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import datetime
 import stomp
 
 from DIRAC import gLogger, gConfig
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 
-__RCSID__ = "$Id$"
-
 
 class NagiosConnector(object):
     """Bundles functions in the stomp library for sending SAMJob-Results to SAM-
