@@ -12,15 +12,8 @@
 
 A tree ox XMLNodes.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import xml.dom.minidom
 
-__RCSID__ = "$Id$"
-
-
 ################################################################################
 
 
@@ -124,57 +117,3 @@ class XMLTreeParser(object):
         if node.nodeType == node.TEXT_NODE or node.nodeType == node.CDATA_SECTION_NODE:
             data = node.data
         return data
-
-
-# Utilies for XML Report
-
-
-def addChildNode(parentNode, tag, returnChildren, args):
-    """
-    :param parentNode:
-      node where the new node is going to be appended
-    :param tag:
-      name if the XML element to be created
-    :param returnChildren:
-      flag to return or not the children node, used to avoid unused variables
-    :param args:
-      possible attributes of the element
-    """
-
-    allowedTags = ["Job", "TypedParameter", "InputFile", "OutputFile", "Parameter", "Replica", "SimulationCondition"]
-
-    def genJobDict(configName, configVersion, ldate, ltime):
-        return {"ConfigName": configName, "ConfigVersion": configVersion, "Date": ldate, "Time": ltime}
-
-    def genTypedParameterDict(name, value, typeP="Info"):
-        return {"Name": name, "Value": value, "Type": typeP}
-
-    def genInputFileDict(name):
-        return {"Name": name}
-
-    def genOutputFileDict(name, typeName, typeVersion):
-        return {"Name": name, "TypeName": typeName, "TypeVersion": typeVersion}
-
-    def genParameterDict(name, value):
-        return {"Name": name, "Value": value}
-
-    def genReplicaDict(name, location="Web"):
-        return {"Name": name, "Location": location}
-
-    def genSimulationConditionDict():
-        return {}
-
-    if tag not in allowedTags:
-        # We can also return S_ERROR, but this let's the job keep running.
-        tagsDict = {}
-    else:
-        tagsDict = locals()["gen%sDict" % tag](*args)
-
-    childNode = xml.dom.minidom.Document().createElement(tag)
-    for key, value in tagsDict.items():
-        childNode.setAttribute(key, str(value))
-    parentNode.appendChild(childNode)
-
-    if returnChildren:
-        return (parentNode, childNode)
-    return parentNode
