@@ -10,10 +10,6 @@
 ###############################################################################
 """Unittest for:
 LHCbDIRAC.HCbDIRAC.Core.Utilities.GeneratorLog"""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import pytest
 from LHCbDIRAC.Core.Utilities.GeneratorLog import (
     counterJson,
