@@ -9,14 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Unit tests for LHCbDIRAC utilities."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=protected-access,missing-docstring,invalid-name
-
-__RCSID__ = "$Id$"
-
 import unittest
 import itertools
 import os
