@@ -10,12 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Returns the platform supported by the current WN."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import LbPlatformUtils
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
