@@ -10,12 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Fix incorrect file GUIDs."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 
 import DIRAC
