@@ -25,10 +25,6 @@
               If the command itself is dirac-loop, then the first occurrence only of @arg@ is replaced,
               which allows recursive calls
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import tempfile
 import subprocess
@@ -157,16 +153,18 @@ def main():
             # Look for a path in the line
             # "Real Data" is an exception in BK path (i.e. with space in it)... BKQuery understands without a space
             #    hence for simplicity here, remove the space to allow split() to work ;-)
-            words = arg.replace("Real Data", "RealData").split()
+            words = arg.replace("”", '"').replace("“", '"').replace("Real Data", "RealData").split()
             arg = None
             for word in words:
-                if word.startswith(("/", '"/', "'/")) or ":/" in word:
+                if word.startswith("/") or ":/" in word or '"/' in word or "'/" in word:
                     arg = word
                     break
         # If the argument is between quotes, take what is between the quotes
-        if arg[0] == "'":
+        if not arg:
+            continue
+        if "'/" in arg:
             arg = arg.split("'")[1]
-        elif arg[0] == '"':
+        elif '"/' in arg:
             arg = arg.split('"')[1]
         elif noParse:
             # Consider the whole line is the argument
