@@ -16,10 +16,6 @@
 :synopsis: The PopularityAnalysis Agent generates the popularity CSV file, sends it for analysis to the
            Yandex data popularity service, and sends the result by email
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # imports
 import os
 import json
@@ -35,8 +31,6 @@ from DIRAC.Core.Utilities.Mail import Mail
 
 from LHCbDIRAC.DataManagementSystem.Client.ScanPopularity import scanPopularity
 
-__RCSID__ = "$Id$"
-
 AGENT_NAME = "DataManagement/PopularityAnalysisAgent"
 
 
