@@ -10,12 +10,6 @@
 ###############################################################################
 """Actual engine for adding a DM transformation, called by dirac-dms-add-
 Transformation."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 import json
 from collections import defaultdict
@@ -24,6 +18,7 @@ import DIRAC
 from DIRAC import gLogger
 from DIRAC.Core.Base import Script
 from DIRAC.Core.Utilities.List import breakListIntoChunks
+from DIRAC.Core.Utilities.ObjectLoader import ObjectLoader
 
 from LHCbDIRAC.TransformationSystem.Client.Transformation import Transformation
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
@@ -61,6 +56,43 @@ def _checkMCReplication(bkPaths):
     return obsoleteTrans
 
 
+def getTransformationName(transName, unique):
+    """
+    Get a transformation name from a base name
+    If unique is requested, return None if already exists
+    """
+    tName = transName
+    trial = 0
+    transClient = TransformationClient()
+    while True:
+        # Check if there is already a transformation with that name
+        res = transClient.getTransformation(tName)
+        if res["OK"]:
+            # Transformation already exists
+            if unique:
+                # If unique is required and the transformation is not in a final status, give up
+                if res["Value"]["Status"] not in (
+                    "Archived",
+                    "Cleaned",
+                    "Cleaning",
+                    "Deleted",
+                    "TransformationCleaned",
+                ):
+                    tName = None
+                    gLogger.notice(
+                        "Transformation %s already exists with ID %d, status %s"
+                        % (transName, res["Value"]["TransformationID"], res["Value"]["Status"])
+                    )
+                    break
+            trial += 1
+            # Check again with new name
+            tName = transName + "-" + str(trial)
+        else:
+            # Transformation doesn't exist, OK
+            break
+    return tName
+
+
 def executeAddTransformation(pluginScript):
     """Method for actually adding a DM transformation It takes its options and
     argument values from pluginScript."""
@@ -77,6 +109,8 @@ def executeAddTransformation(pluginScript):
     mcVersionSet = None
     nameOption = None
     checkMCReplication = False
+    bodyPlugin = None
+    transBody = None
 
     switches = Script.getUnprocessedSwitches()
     for opt, val in switches:
@@ -114,7 +148,14 @@ def executeAddTransformation(pluginScript):
             # Force to check all versions
             mcVersionSet = {"all"}
             checkMCReplication = True
+        elif opt == "BodyPlugin":
+            bodyPlugin = val
+        elif opt == "TransBody":
+            transBody = val
 
+    if bodyPlugin and transBody:
+        gLogger.fatal("Cannot specify both BodyPlugin and TransBody")
+        exit(1)
     if userGroup:
         from DIRAC.Core.Security.ProxyInfo import getProxyInfo
 
@@ -317,37 +358,9 @@ def executeAddTransformation(pluginScript):
             gLogger.fatal("Didn't manage to find a name for this transformation, check options")
             DIRAC.exit(1)
         # Find a name for this transformation (transName remains the base name)
-        tName = transName
-        giveUp = False
-        trial = 0
-        while True:
-            # Check if there is already a transformation with that name
-            res = tr.getTransformation(tName)
-            if res["OK"]:
-                # Transformation already exists
-                if unique:
-                    # If unique is required and the transformation is not in a final status, give up
-                    if res["Value"]["Status"] not in (
-                        "Archived",
-                        "Cleaned",
-                        "Cleaning",
-                        "Deleted",
-                        "TransformationCleaned",
-                    ):
-                        giveUp = True
-                        gLogger.notice(
-                            "Transformation %s already exists with ID %d, status %s"
-                            % (transName, res["Value"]["TransformationID"], res["Value"]["Status"])
-                        )
-                        break
-                trial += 1
-                # Check again with new name
-                tName = transName + "-" + str(trial)
-            else:
-                # Transformation doesn't exist, OK
-                break
+        tName = getTransformationName(transName, unique)
         # If needed, skip this BK query
-        if giveUp:
+        if tName is None:
             continue
 
         transformation.setTransformationName(tName)
@@ -355,17 +368,33 @@ def executeAddTransformation(pluginScript):
         transformation.setDescription(longName[:255])
         transformation.setLongDescription(longName)
         transformation.setType(transType)
-        transBody = None
-        if transType == "Removal":
-            if plugin == "DestroyDataset":
-                transBody = "removal;RemoveFile"
-            elif plugin == "DestroyDatasetWhenProcessed":
-                plugin = "DeleteReplicasWhenProcessed"
-                transBody = "removal;RemoveFile"
-                # Set the polling period to 0 if not defined
-                pluginParams.setdefault("Period", 0)
-            else:
-                transBody = "removal;RemoveReplica"
+
+        # Rename plugin
+        if plugin == "DestroyDatasetWhenProcessed":
+            plugin = "DeleteReplicasWhenProcessed"
+            # Set the polling period to 0 if not defined
+            pluginParams.setdefault("Period", 0)
+
+        # If we have a body plugin, load it
+        if bodyPlugin:
+            objLoader = ObjectLoader()
+            _class = objLoader.loadObject("TransformationSystem.Client.BodyPlugin.%s" % bodyPlugin, bodyPlugin)
+
+            if not _class["OK"]:
+                raise Exception(_class["Message"])
+            # TODO: handle the case of a body plugin with arguments
+            transBody = _class["Value"]()
+        else:
+            # If we don't have a body, define it for Removal transformations
+            if not transBody and transType == "Removal":
+                if plugin == "DestroyDataset":
+                    transBody = "removal;RemoveFile"
+                elif plugin == "DestroyDatasetWhenProcessed":
+                    transBody = "removal;RemoveFile"
+                else:
+                    transBody = "removal;RemoveReplica"
+
+        if transBody:
             transformation.setBody(transBody)
 
         if pluginSEParams:
@@ -528,7 +557,13 @@ def executeAddTransformation(pluginScript):
                 if not res["OK"]:
                     errMsg = "Could not add files to transformation"
                     break
-                gLogger.notice("%d files successfully added to transformation" % len(res["Value"]))
+                gLogger.notice("%d files successfully added to transformation" % len(res["Value"]["Successful"]))
+                if res["Value"]["Failed"]:
+                    errors = defaultdict(int)
+                    for error in res["Value"]["Failed"].values():
+                        errors[error] += 1
+                    for error, count in errors.items():
+                        gLogger.always("Failed to add %d files to transformation %d:" % (count, transID), error)
             if requestID:
                 transformation.setTransformationFamily(requestID)
             if start:
