@@ -14,10 +14,6 @@
     - Transformation
     - File Catalog
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import time
 import ast
 import os
@@ -262,6 +258,8 @@ class ConsistencyChecks(DiracConsistencyChecks):
         """get the replicas using the standard DataManager.getReplicas()"""
         present = set()
         notPresent = set()
+        if not lfns:
+            return [], []
         lfns = set(lfns)
 
         chunkSize = 100
@@ -1158,9 +1156,12 @@ class ConsistencyChecks(DiracConsistencyChecks):
             progressBar.endLoop()
 
         # Reduce the set of files to those at requested SEs if specified
+        otherReplicas = []
         if self._seList:
             notAtSE = []
             for lfn, ses in replicas.items():
+                if set(ses) - self._seList:
+                    otherReplicas.append(lfn)
                 replicas[lfn] = set(ses) & self._seList
                 if not replicas[lfn]:
                     notAtSE.append(lfn)
@@ -1249,7 +1250,7 @@ class ConsistencyChecks(DiracConsistencyChecks):
         for lfn in replicas:
             # get the lfn checksum from the LFC
             replicaDict = replicas[lfn]
-            oneGoodReplica = False
+            oneGoodReplica = False if lfn not in otherReplicas else True
             allGoodReplicas = True
             lfcChecksum = csDict[lfn].pop("LFCChecksum")
             for se in replicaDict:
