@@ -9,12 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Methods for scanning the popularity table."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 import time
 from datetime import datetime, timedelta
