@@ -15,12 +15,6 @@
 
 :synopsis: Lightweight possbile client to the StorageUsageDB.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Base.Client import Client, createClient
 
 
