@@ -15,9 +15,6 @@
 
 :synopsis: StorageUsageDB class is a front-end to the Storage Usage Database.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import six
 
 import os
@@ -26,8 +23,6 @@ import os
 from DIRAC import S_OK, S_ERROR
 from DIRAC.Core.Base.DB import DB
 
-__RCSID__ = "$Id$"
-
 
 def _standardDirectory(dirPath):
     """This adds a / at the end of the path if not there"""
