@@ -17,12 +17,6 @@
 If --FixFC is set, remove from SE and FC
 If --FixBK is set and no replica flag, set replica flag in the BK
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
