@@ -11,12 +11,6 @@
 ###############################################################################
 """Given a (list of) LFNs and SEs, check for existence of a file and register
 in the FC if the file exists."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
