@@ -11,12 +11,6 @@
 ###############################################################################
 """Remove the given file or a list of files from the File Catalog and from the
 storage."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
