@@ -8,15 +8,9 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 ############################################################
 
 """LHCbDIRAC.Interfaces.API package.
 
 This contains the LHCb specific API plugins for DIRAC.
 """
-
-__RCSID__ = "$Id$"
