@@ -17,10 +17,6 @@ Please note that this agent is a hybrid agent that sends aggregated emails for b
 LHCbDIRAC.ProductionManagementSystem.Utilities.Utils.informPeople and
 LHCbDIRAC.ProductionManagementSystem.Agent.ProductionStatusAgent._mailProdManager
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import sqlite3
 import DIRAC
@@ -30,8 +26,6 @@ from DIRAC.Interfaces.API.DiracAdmin import DiracAdmin
 from DIRAC.ConfigurationSystem.Client import PathFinder
 from LHCbDIRAC.ProductionManagementSystem.Utilities.Utils import _getMemberMails
 
-__RCSID__ = "$Id$"
-
 AGENT_NAME = "ProductionManagement/NotifyAgent"
 
 
