@@ -33,10 +33,6 @@ To do: review usage of production API(s) and re-factor into Production Client
 
 AZ 10.14: merged with a part from RequestTrackingAgent to avoid race conditions
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import time
 import os
 import sqlite3
@@ -76,8 +72,6 @@ KNOWN_TASK_STATES = [
     "Waiting",
 ]
 
-__RCSID__ = "$Id$"
-
 
 class ProductionStatusAgent(AgentModule):
     """Usual DIRAC agent."""
@@ -572,7 +566,7 @@ class ProductionStatusAgent(AgentModule):
                     if inputID in summary["prods"]:
                         inputState = summary["prods"][inputID]["state"]
                     else:
-                        inputState = inputTransformStatuses[inputID]
+                        inputState = inputTransformStatuses.get(inputID, "Unknown")
                     if inputState not in ["Archived", "Completed", "Finished"]:
                         self.log.info(
                             "Marking hasActiveInput=True for",
