@@ -9,11 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Module holding MCStatsClient class."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-
 from DIRAC.Core.Base.Client import Client, createClient
 
 
