@@ -10,10 +10,6 @@
 ###############################################################################
 """DIRAC ProductionRequestDB class is a front-end to the repository database
 containing Production Requests and other related tables."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # Defined states:
 # 'New'
 # 'BK OK'
@@ -38,8 +34,6 @@ from DIRAC.Core.Base.DB import DB
 
 from LHCbDIRAC.ProductionManagementSystem.Utilities.Utils import informPeople
 
-__RCSID__ = "$Id$"
-
 
 class ProductionRequestDB(DB):
     """DB class for ProductionManagement/ProductionRequestDB."""
@@ -215,7 +209,7 @@ class ProductionRequestDB(DB):
 
         if rec["RequestState"]:
             if not rec["RequestState"] in ["New", "BK Check", "Submitted"]:
-                return S_ERROR("The request can't be created in '%s' state" % rec["requestState"])
+                return S_ERROR("The request can't be created in '%s' state" % rec["RequestState"])
             if rec["RequestState"] != "New":
                 # !!! full information check must be here, but currently in the JS...
                 # so we only check EventType consistency
