@@ -10,13 +10,6 @@
 ###############################################################################
 """ DIRAC service that expose access for MCStatsElasticDBs (several ElasticSearch DBs)
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-
-__RCSID__ = "$Id$"
-
 import six
 
 from DIRAC import S_OK
