@@ -24,10 +24,6 @@
       - for the MC: just set pr.prodsToLaunch = [1]
       - for the merge and/or stripping: set pr.prodsToLaunch, then set pr.previousProdID
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from six.moves import range
 
 import ast
@@ -39,9 +35,7 @@ Script.parseCommandLine()
 from DIRAC import gConfig, gLogger, exit as DIRACexit
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequest import ProductionRequest
 
-__RCSID__ = "$Id$"
-
-gLogger = gLogger.getSubLogger("MCSimulation_run.py")
+gLogger = gLogger.getSubLogger("MCSimulation_simplified_run.py")
 currentSetup = gConfig.getValue("DIRAC/Setup")
 
 pr = ProductionRequest()
