@@ -22,10 +22,6 @@ Exotic things you might want to do:
   pre: remember to check if your input file is online, if not use lcg-bringonline <PFN>
 * run only part of the request on the Grid:
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from six.moves import range
 
 import ast
@@ -37,8 +33,6 @@ Script.parseCommandLine()
 from DIRAC import gConfig, gLogger, exit as DIRACexit
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequest import ProductionRequest
 
-__RCSID__ = "$Id$"
-
 gLogger = gLogger.getSubLogger("RecoStripping_run.py")
 currentSetup = gConfig.getValue("DIRAC/Setup")
 
