@@ -31,12 +31,6 @@ The following switches and options are provided.
 - omitMerge     : omit all merge production
 - noFiles       : do not request file information
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from datetime import datetime
 import sys
 
