@@ -12,12 +12,6 @@
 
 POLICIESMETA_LHCB policies POLICIESMETA
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.ResourceStatusSystem.Policy.Configurations import POLICIESMETA
 
 # LHCb Policies
