@@ -13,14 +13,8 @@
 DownHillPropagationPolicy.__bases__:
   DIRAC.ResourceStatusSystem.PolicySystem.PolicyBase.PolicyBase
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC.ResourceStatusSystem.PolicySystem.PolicyBase import PolicyBase
 
-__RCSID__ = "$Id$"
-
 # ..............................................................................
 #
 #
