@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_Resources_Catalog_BookkeepingDBClient."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=protected-access, missing-docstring, invalid-name, line-too-long
 
 import unittest
@@ -23,8 +19,6 @@ import six
 from DIRAC import gLogger
 import LHCbDIRAC.Resources.Catalog.BookkeepingDBClient as moduleTested
 
-__RCSID__ = "$Id$"
-
 ################################################################################
 
 
