@@ -14,10 +14,6 @@ files in input to a transformation.
 
 A pickle file is used as a cache.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import time
 import datetime
@@ -37,9 +33,6 @@ from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClie
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
 AGENT_NAME = "Transformation/BookkeepingWatchAgent"
-
-__RCSID__ = "$Id$"
-
 gSynchro = Synchronizer()
 
 
