@@ -9,12 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Simple extension of base class."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 from DIRAC.TransformationSystem.Agent.ValidateOutputDataAgent import (
