@@ -9,14 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Extension of DIRAC Task Manager."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC.TransformationSystem.Client.WorkflowTasks import WorkflowTasks
 
-__RCSID__ = "$Id$"
-
 COMPONENT_NAME = "LHCbTaskManager"
 
 
