@@ -15,12 +15,6 @@ information in order to automate the task of job preparation for high
 level transformations. This class is typically used as a base class for
 more specific data processing databases
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import threading
 import copy
 import re
