@@ -11,12 +11,6 @@
 ###############################################################################
 """Debug files status for a (list of) transformations It is possible to do
 minor fixes to those files, using options."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
