@@ -11,14 +11,9 @@
 """ Analyse XMLSummary module and PoolCatalog in order to monitor the files access
     We send data to the accounting (Site -> SE : fail/success)
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from collections import defaultdict
 
+import LHCbDIRAC
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.AccountingSystem.Client.Types.DataOperation import DataOperation
 from DIRAC.Resources.Catalog.PoolXMLCatalog import PoolXMLCatalog
@@ -35,7 +30,7 @@ class AnalyseFileAccess(ModuleBase):
         self.log = gLogger.getSubLogger("AnalyseFileAccess")
         super(AnalyseFileAccess, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
         self.XMLSummary = ""
         self.XMLSummary_o = None
         self.poolXMLCatName = ""
