@@ -10,14 +10,9 @@
 ###############################################################################
 """Prepare a file (data.py) which is consumed by Ganga, containing the input
 files as resolved in the workflow."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC import S_OK, S_ERROR, gLogger
 
+import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.Core.Utilities.GangaDataFile import GangaDataFile
 
@@ -35,7 +30,7 @@ class CreateDataFile(ModuleBase):
         self.gangaFileName = "data.py"
         self.poolXMLCatName = "pool_xml_catalog.xml"
         self.persistency = ""
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
 
     def _resolveInputVariables(self):
         """By convention the module parameters are resolved here."""
