@@ -10,14 +10,9 @@
 ###############################################################################
 """Module to upload specified job output files according to the parameters
 defined in the user workflow."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 
+import LHCbDIRAC
 from DIRAC import S_OK, S_ERROR, gLogger, gConfig
 from DIRAC.Core.Utilities import DEncode
 from DIRAC.RequestManagementSystem.Client.Request import Operation
@@ -33,7 +28,7 @@ class FileUsage(ModuleBase):
         """Module initialization."""
         self.log = gLogger.getSubLogger("FileUsage")
         super(FileUsage, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
         self.dataUsageClient = DataUsageClient()
 
     #############################################################################
