@@ -10,10 +10,6 @@
 ###############################################################################
 """LHCbScript is very similar to DIRAC Script module, but consider LHCb
 environment."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 
 from DIRAC import gLogger
