@@ -10,16 +10,11 @@
 ###############################################################################
 """StepAccounting module performs several common operations at the end of a
 workflow step, in particular prepares and sends the step accounting data."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC import S_OK, S_ERROR, gConfig, gLogger
 from DIRAC.Core.Utilities import Time
 from DIRAC.Workflow.Utilities.Utils import getStepCPUTimes
 
+import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.AccountingSystem.Client.Types.JobStep import JobStep
 
@@ -35,7 +30,7 @@ class StepAccounting(ModuleBase):
         self.dsc = None
         self.stepStat = None
 
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
 
     ########################################################################
 
