@@ -12,9 +12,6 @@
 
     Mostly used by BOINC
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import six
 import json
 from DIRAC import S_OK, S_ERROR, gLogger
@@ -35,8 +32,6 @@ from DIRAC.WorkloadManagementSystem.Client.JobManagerClient import JobManagerCli
 from DIRAC.WorkloadManagementSystem.Client.PilotManagerClient import PilotManagerClient
 from DIRAC.WorkloadManagementSystem.Client.JobMonitoringClient import JobMonitoringClient
 
-__RCSID__ = "$Id$"
-
 # pylint: disable=no-self-use
 
 
